@@ -594,6 +594,7 @@ append_sections_from_file (GtkBuilder *builder, const gchar *path, const char *d
     g_free (entry->name);
     g_free (entry->reverse_entry);
   }
+  g_free (keys);
 
   g_free (keylist);
 }
@@ -1665,6 +1666,7 @@ find_free_settings_path ()
       else
         g_free (tmp);
     }
+  g_strfreev (used_names);
 
   return dir;
 }
